@@ -1,17 +1,17 @@
-'''
+"""
 drawing rectangles for debugging
-'''
+"""
 
 
+from PIL import Image, ImageDraw
+
 from discogui.screenrect import ScreenRect
-import Image
-import ImageDraw
 
 
-def draw_textrect(im, rect, text=None, color='red'):
-    '''
+def draw_textrect(im, rect, text=None, color="red"):
+    """
     draw rectangle and text in center
-    '''
+    """
     im = im.copy()
     draw = ImageDraw.Draw(im)
     draw.rectangle(rect, outline=color, fill=None)
@@ -22,10 +22,10 @@ def draw_textrect(im, rect, text=None, color='red'):
     return im
 
 
-def draw_indexed_rect_list(im, lsrect, color='red'):
-    '''
+def draw_indexed_rect_list(im, lsrect, color="red"):
+    """
     draw rectangles and index in center
-    '''
+    """
     index = 0
     for x in lsrect:
         im = draw_textrect(im, x, str(index), color=color)
@@ -34,10 +34,10 @@ def draw_indexed_rect_list(im, lsrect, color='red'):
 
 
 def _test():
-    im = Image.new('RGB', (522, 222), 'grey')
-    x = draw_indexed_rect_list(im,
-                               [(1, 111, 111, 61), (221, 1, 111, 61), ],)
-    x.show()
+    im = Image.new("RGB", (522, 222), "grey")
+    x = draw_indexed_rect_list(im, [(1, 111, 111, 61), (221, 1, 111, 61),],)
+    x.save("rect.png")
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     _test()
