@@ -1,9 +1,8 @@
 import logging
 from logging import DEBUG
+from pathlib import Path
 from tempfile import gettempdir, mkdtemp
 
-from path import Path
-
 from discogui.draw import draw_indexed_rect_list
 
 log = logging.getLogger(__name__)
@@ -28,14 +27,13 @@ def img_log(im, text):
     global img_ind
     if not img_dir:
         root = Path(gettempdir()) / "img_log"
-        if not root.exists():
-            root.makedirs()
+        root.mkdir(exist_ok=True)
         img_dir = Path(mkdtemp(prefix="img_debug_", suffix="", dir=root))
     if CROP_RECT:
         im = im.crop(CROP_RECT)
-    fname = str(img_dir / str(img_ind) + "_" + text + ".png")
+    fname = str(img_dir / (str(img_ind) + "_" + text + ".png"))
     im.save(fname)
-    log.debug("image was saved:" + fname)
+    log.debug("image was saved: " + fname)
     img_ind += 1
 
 
