@@ -1,14 +1,16 @@
-import pymouse
 import sys
 
+import pymouse
+
 
 def PyMouse():
-    '''
+    """
     wrapper, turn off print coming from Xlib.ext.randr
-    '''
+    """
     # Quick, turn off printing!
     class dummyStream:
-        ''' dummyStream behaves like a stream but does nothing. '''
+        """ dummyStream behaves like a stream but does nothing. """
+
         def __init__(self):
             pass
 
@@ -23,6 +25,7 @@ def PyMouse():
 
         def close(self):
             pass
+
     # Copy old print deals
     old = sys.stdout
     # redirect all print deals
