@@ -6,7 +6,7 @@ from discogui.hover import active_rectangles
 
 def test_zenity():
     with SmartDisplay() as disp:
-        with EasyProcess("zenity --warning"):
+        with EasyProcess(["zenity", "--warning"]):
             disp.waitgrab()
             ls = active_rectangles()
             assert len(ls) == 1
@@ -14,7 +14,7 @@ def test_zenity():
 
 def test_notab():
     with SmartDisplay() as disp:
-        with EasyProcess("xmessage -buttons x,y,z hi"):
+        with EasyProcess(["xmessage", "-buttons", "x,y,z", "hi"]):
             disp.waitgrab()
             ls = active_rectangles(grid=10)
             assert len(ls) == 3
@@ -22,7 +22,7 @@ def test_notab():
 
 def test_gmessage():
     with SmartDisplay() as disp:
-        with EasyProcess("gmessage -buttons x,y,z hi"):
+        with EasyProcess(["gmessage", "-buttons", "x,y,z", "hi"]):
             disp.waitgrab()
             ls = active_rectangles()
             assert len(ls) == 3
